# Experiment


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**active** | **bool** |  | [optional] 
**name** | **str** |  | 
**hypothesis** | **str** |  | 
**control** | **int** |  | 
**treatments** | **list[int]** |  | [optional] 
**notion_url** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


